# QuOsc

QuOsc is a python package for simulating quantum oscillations in torque magnetometry. It performs the following steps:

1. Read the `interpolation.bt2` file generated by BoltzTraP2, to read the interpolated band structure and generate the Fermi surface.
2. For each magnetic field direction, find the extremal cross-sections of the Fermi surface.
3. For the extremal cross-sections, calculate the quantum oscillation frequencies, effective masses, and other relevant parameters.
4. Use the calculated parameters to simulate the quantum oscillations in torque magnetometry and take FFT to extract the quantum oscillation frequencies.

## Installation

To install QuOsc, run the following command:

```bash
pip install quosc
```

## Usage

